@@ -1,2 +1,3 @@
 from .shell import Shell
-shell = Shell()
+
+Shell()
